==> engine-xml-3.8.1-sources.jar: com/xebialabs/deployit/engine/xml/DateTimeAdapter.java <==
package com.xebialabs.deployit.engine.xml;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.Locale;
import java.util.TimeZone;

import javax.ws.rs.ext.Provider;
import javax.xml.bind.annotation.adapters.XmlAdapter;

import org.jboss.resteasy.spi.StringConverter;
import org.joda.time.DateTime;
import org.joda.time.format.DateTimeFormat;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import static java.lang.String.format;

@Provider
public class DateTimeAdapter extends XmlAdapter<String, DateTime> implements StringConverter<DateTime> {
    public static final String FALLBACK = "yyyy-MM-dd'T'HH:mm:ss.SSSZ";

    /**
     * List of possible RFC822 date formats. From <http://jimyjoshi.com/blog/2007/08/rfc822dateparsinginjava.html>.
     */
    protected static final String rfc822DateFormats[] = new String[]{FALLBACK, "EEE, dd MMM yy HH:mm:ss z", "EEE, dd MMM yy HH:mm z", "EEE, dd MMM yyyy HH:mm:ss z",
            "EEE, dd MMM yyyy HH:mm z", "dd MMM yy HH:mm z", "dd MMM yy HH:mm:ss z", "dd MMM yyyy HH:mm z", "dd MMM yyyy HH:mm:ss z",
            "EEE MMM dd HH:mm:ss zzz yyyy", "EEE, dd MMM yyyy z"};

    @Override
    public DateTime unmarshal(String v) {
        DateTime dateTime = null;
        for (String rfc822DateFormat : rfc822DateFormats) {
            try {
                SimpleDateFormat simpleDateFormat = new SimpleDateFormat(rfc822DateFormat, Locale.ENGLISH);
                simpleDateFormat.setTimeZone(TimeZone.getTimeZone("UTC"));
                Date parse = simpleDateFormat.parse(v);
                Calendar cal = Calendar.getInstance(Locale.ENGLISH);
                cal.setTimeZone(TimeZone.getTimeZone("UTC"));
                cal.setTime(parse);
                dateTime = new DateTime(cal);
//				dateTime = DateTimeFormat.forPattern(rfc822DateFormat).withLocale(Locale.ENGLISH).parseDateTime(v);
                break;
            } catch (ParseException ignore) {
                logger.trace(format("Failed to parse [%s] using [%s]", v, rfc822DateFormat), ignore);
            }
        }

        if (dateTime == null) {
            throw new IllegalArgumentException(format("Could not parse date [%s] using RFC822 pattern.", v));
        }
        return dateTime;
    }

    @Override
    public String marshal(DateTime v) {
        return DateTimeFormat.forPattern(FALLBACK).print(v);
    }

    @Override
    public DateTime fromString(String rfc822DateFormat) {
        return unmarshal(rfc822DateFormat);
    }

    @Override
    public String toString(DateTime value) {
        return marshal(value);
    }

    private static final Logger logger = LoggerFactory.getLogger(DateTimeAdapter.class);
}

==> engine-xml-3.8.3-sources.jar: com/xebialabs/deployit/engine/xml/DateTimeAdapter.java <==
package com.xebialabs.deployit.engine.xml;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.Locale;
import java.util.TimeZone;

import javax.ws.rs.ext.Provider;
import javax.xml.bind.annotation.adapters.XmlAdapter;

import org.jboss.resteasy.spi.StringConverter;
import org.joda.time.DateTime;
import org.joda.time.format.DateTimeFormat;
import org.joda.time.format.ISODateTimeFormat;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import static java.lang.String.format;

@Provider
public class DateTimeAdapter extends XmlAdapter<String, DateTime> implements StringConverter<DateTime> {
    public static final String FALLBACK = "yyyy-MM-dd'T'HH:mm:ss.SSSZ";

    /**
     * List of possible RFC822 date formats. From <http://jimyjoshi.com/blog/2007/08/rfc822dateparsinginjava.html>.
     */
    protected static final String rfc822DateFormats[] = new String[]{FALLBACK, "EEE, dd MMM yy HH:mm:ss z", "EEE, dd MMM yy HH:mm z", "EEE, dd MMM yyyy HH:mm:ss z",
            "EEE, dd MMM yyyy HH:mm z", "dd MMM yy HH:mm z", "dd MMM yy HH:mm:ss z", "dd MMM yyyy HH:mm z", "dd MMM yyyy HH:mm:ss z",
            "EEE MMM dd HH:mm:ss zzz yyyy", "EEE, dd MMM yyyy z"};

    @Override
    public DateTime unmarshal(String v) {
        DateTime dateTime = null;
        
        dateTime = parseISO8601(v);
        if (dateTime != null) {
            return dateTime;
        }

        for (String rfc822DateFormat : rfc822DateFormats) {
            try {
                SimpleDateFormat simpleDateFormat = new SimpleDateFormat(rfc822DateFormat, Locale.ENGLISH);
                simpleDateFormat.setTimeZone(TimeZone.getTimeZone("UTC"));
                Date parse = simpleDateFormat.parse(v);
                Calendar cal = Calendar.getInstance(Locale.ENGLISH);
                cal.setTimeZone(TimeZone.getTimeZone("UTC"));
                cal.setTime(parse);
                dateTime = new DateTime(cal);
                break;
            } catch (ParseException ignore) {
                logger.trace(format("Failed to parse [%s] using [%s]", v, rfc822DateFormat), ignore);
            }
        }

        if (dateTime == null) {
            throw new IllegalArgumentException(format("Could not parse date [%s] using ISO8601 or RFC822 pattern.", v));
        }
        return dateTime;
    }

    private DateTime parseISO8601(String v) {
        try {
            return ISODateTimeFormat.dateTime().withZoneUTC().parseDateTime(v);
        } catch(IllegalArgumentException e) {
            return null;
        }
    }

    @Override
    public String marshal(DateTime v) {
        return DateTimeFormat.forPattern(FALLBACK).print(v);
    }

    @Override
    public DateTime fromString(String rfc822DateFormat) {
        return unmarshal(rfc822DateFormat);
    }

    @Override
    public String toString(DateTime value) {
        return marshal(value);
    }

    private static final Logger logger = LoggerFactory.getLogger(DateTimeAdapter.class);
}
